@@ -136,7 +136,7 @@ pub fn run(config: Config) -> Result<(), Box<dyn Error>> {
     } else if &config.content_type.to_ascii_lowercase() == "--raw" {
         data = config.content.to_string();
     } else {
-        return Err("Invalid content type".into())
+        return Err("Invalid content type".into());
     }
 
     let result: String = mock_any(
@@ -146,7 +146,7 @@ pub fn run(config: Config) -> Result<(), Box<dyn Error>> {
         } else if &config.randomize.to_lowercase() == "--no-randomize" {
             false
         } else {
-            return Err("Invalid argument".into())
+            return Err("Invalid argument".into());
         },
     );
 
